@@ -32,7 +32,14 @@ class API:
             verifier=oauth_verifier
         )
 
-        return oauth.fetch_access_token(self._access_token_url)
+        token = oauth.fetch_access_token(self._access_token_url)
+        self.set_access_token(token['oauth_token'], token['oauth_token_secret'])
+        return token
+
+    def set_access_token(self, access_token, access_token_secret):
+        self._access_token = access_token
+        self._access_token_secret = access_token_secret
+        self._auth = OAuth1(self._consumer_key, self._consumer_secret, access_token, access_token_secret)
 
     def get(self, endpoint, **kwargs):
         return self.request('get', endpoint, params=kwargs)
